import * as i0 from '@angular/core';
import { Directive, Input, HostListener, NgModule } from '@angular/core';

class InputNumberDirective {
    constructor(el) {
        this.el = el;
        this.navigationKeys = [
            'Backspace',
            'Delete',
            'Tab',
            'Escape',
            'Enter',
            'Home',
            'End',
            'ArrowLeft',
            'ArrowRight',
            'Clear',
            'Copy',
            'Paste',
        ];
        this.decimal = false;
        this.decimalSeparator = '.';
        this.regex = null;
        this.inputElement = el.nativeElement;
    }
    ngOnChanges(changes) {
        if (changes['pattern']) {
            this.regex = this.pattern ? RegExp(this.pattern) : null;
        }
        if (changes['min']) {
            const maybeMin = Number(this.min);
            this.min = isNaN(maybeMin) ? -Infinity : maybeMin;
        }
        if (changes['max']) {
            const maybeMax = Number(this.max);
            this.max = isNaN(maybeMax) ? Infinity : maybeMax;
        }
    }
    onBeforeInput(e) {
        if (isNaN(Number(e.data))) {
            // if (
            //   e.data === this.decimalSeparator ||
            //   (e.data === this.negativeSign && this.allowNegatives)
            // ) {
            //   return; // go on
            // }
            e.preventDefault();
            e.stopPropagation();
        }
    }
    onKeyDown(e) {
        if (this.navigationKeys.indexOf(e.key) > -1 || // Allow: navigation keys: backspace, delete, arrows etc.
            ((e.key === 'a' || e.code === 'KeyA') && e.ctrlKey === true) || // Allow: Ctrl+A
            ((e.key === 'c' || e.code === 'KeyC') && e.ctrlKey === true) || // Allow: Ctrl+C
            ((e.key === 'v' || e.code === 'KeyV') && e.ctrlKey === true) || // Allow: Ctrl+V
            ((e.key === 'x' || e.code === 'KeyX') && e.ctrlKey === true) || // Allow: Ctrl+X
            ((e.key === 'a' || e.code === 'KeyA') && e.metaKey === true) || // Allow: Cmd+A (Mac)
            ((e.key === 'c' || e.code === 'KeyC') && e.metaKey === true) || // Allow: Cmd+C (Mac)
            ((e.key === 'v' || e.code === 'KeyV') && e.metaKey === true) || // Allow: Cmd+V (Mac)
            ((e.key === 'x' || e.code === 'KeyX') && e.metaKey === true) // Allow: Cmd+X (Mac)
        ) {
            // let it happen, don't do anything
            return;
        }
        let newValue = '';
        if (this.decimal && e.key === this.decimalSeparator) {
            newValue = this.forecastValue(e.key);
            if (newValue.split(this.decimalSeparator).length > 2) {
                // has two or more decimal points
                e.preventDefault();
                return;
            }
            else {
                //   this.hasDecimalPoint = newValue.indexOf(this.decimalSeparator) > -1;
                return; // Allow: only one decimal point
            }
        }
        // Ensure that it is a number and stop the keypress
        if (e.key === ' ' || isNaN(Number(e.key))) {
            e.preventDefault();
            return;
        }
        newValue = newValue || this.forecastValue(e.key);
        // check the input pattern RegExp
        if (this.regex) {
            if (!this.regex.test(newValue)) {
                e.preventDefault();
                return;
            }
        }
        const newNumber = Number(newValue);
        if (newNumber > this.max || newNumber < this.min) {
            e.preventDefault();
        }
    }
    forecastValue(key) {
        var _a, _b;
        const selectionStart = (_a = this.inputElement.selectionStart) !== null && _a !== void 0 ? _a : 0;
        const selectionEnd = (_b = this.inputElement.selectionEnd) !== null && _b !== void 0 ? _b : 0;
        const oldValue = this.inputElement.value;
        return (oldValue.substring(0, selectionStart) +
            key +
            oldValue.substring(selectionEnd));
    }
}
InputNumberDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.0.4", ngImport: i0, type: InputNumberDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
InputNumberDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "15.0.4", type: InputNumberDirective, selector: "[inputNumberValidator]", inputs: { decimal: "decimal", decimalSeparator: "decimalSeparator", min: "min", max: "max", pattern: "pattern" }, host: { listeners: { "beforeinput": "onBeforeInput($event)", "keydown": "onKeyDown($event)" } }, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.0.4", ngImport: i0, type: InputNumberDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[inputNumberValidator]',
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { decimal: [{
                type: Input
            }], decimalSeparator: [{
                type: Input
            }], min: [{
                type: Input
            }], max: [{
                type: Input
            }], pattern: [{
                type: Input
            }], onBeforeInput: [{
                type: HostListener,
                args: ['beforeinput', ['$event']]
            }], onKeyDown: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }] } });

class InputValidatorsModule {
}
InputValidatorsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.0.4", ngImport: i0, type: InputValidatorsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
InputValidatorsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.0.4", ngImport: i0, type: InputValidatorsModule, declarations: [InputNumberDirective], exports: [InputNumberDirective] });
InputValidatorsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.0.4", ngImport: i0, type: InputValidatorsModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.0.4", ngImport: i0, type: InputValidatorsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        InputNumberDirective
                    ],
                    imports: [],
                    exports: [
                        InputNumberDirective
                    ]
                }]
        }] });

/*
 * Public API Surface of input-validators
 */

/**
 * Generated bundle index. Do not edit.
 */

export { InputNumberDirective, InputValidatorsModule };
//# sourceMappingURL=goodbetterbist-input-validators.mjs.map
//# sourceMappingURL=goodbetterbist-input-validators.mjs.map
